@@ -3,10 +3,10 @@
  *
  * Ref: NIST FIPS PUB 180-2 Secure Hash Standard
  *
- * Copyright (C) 2003-2011 Mark Shelor, All Rights Reserved
+ * Copyright (C) 2003-2012 Mark Shelor, All Rights Reserved
  *
- * Version: 5.60
- * Thu Mar  3 05:26:42 MST 2011
+ * Version: 5.73
+ * Wed Oct 31 04:32:44 MST 2012
  *
  */
 
@@ -211,6 +211,7 @@ unsigned char	*shadigest	(_SHA_STATE);
 char		*shahex		(_SHA_STATE);
 char		*shabase64	(_SHA_STATE);
 int		 shadsize	(_SHA_STATE);
+int		 shaalg		(_SHA_STATE);
 SHA		*shadup		(_SHA_STATE);
 int		 shadump	(_SHA_FNAME, _SHA_STATE);
 SHA		*shaload	(_SHA_FNAME);
